@@ -1,7 +1,7 @@
 use std::collections::BTreeSet;
 
 use poem_openapi::{
-    registry::{MetaTag, Registry},
+    registry::{MetaExternalDocument, MetaTag, Registry},
     Tags,
 };
 
@@ -62,13 +62,42 @@ async fn meta() {
             MetaTag {
                 name: "UserOperations",
                 description: Some("User operations"),
+                external_docs: None
             },
             MetaTag {
                 name: "PetOperations",
                 description: Some("Pet operations"),
+                external_docs: None
             }
         ]
         .into_iter()
         .collect::<BTreeSet<_>>()
     );
 }
+
+#[tokio::test]
+async fn external_docs() {
+    #[derive(Tags)]
+    #[allow(dead_code)]
+    enum MyTags {
+        #[oai(
+            external_docs = "https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md"
+        )]
+        UserOperations,
+    }
+
+    let mut registry = Registry::new();
+    MyTags::UserOperations.register(&mut registry);
+    assert_eq!(
+        registry.tags.into_iter().next().unwrap(),
+        MetaTag {
+            name: "UserOperations",
+            description: None,
+            external_docs: Some(MetaExternalDocument {
+                url: "https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md"
+                    .to_string(),
+                description: None
+            })
+        }
+    );
+}
