@@ -26,7 +26,10 @@ fn test_u64() {
         n: u64,
     }
 
-    assert_eq!(A::parse_from_json(json!({ "n": 1 })).unwrap(), A { n: 1 });
+    assert_eq!(
+        A::parse_from_json(Some(json!({ "n": 1 }))).unwrap(),
+        A { n: 1 }
+    );
 }
 
 #[test]
@@ -37,9 +40,12 @@ fn test_multiple_of() {
         n: i32,
     }
 
-    assert_eq!(A::parse_from_json(json!({ "n": 20 })).unwrap(), A { n: 20 });
     assert_eq!(
-        A::parse_from_json(json!({ "n": 25 }))
+        A::parse_from_json(Some(json!({ "n": 20 }))).unwrap(),
+        A { n: 20 }
+    );
+    assert_eq!(
+        A::parse_from_json(Some(json!({ "n": 25 })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n` verification failed. multipleOf(10)"
@@ -59,15 +65,15 @@ fn test_maximum() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "n": 400 })).unwrap(),
+        A::parse_from_json(Some(json!({ "n": 400 }))).unwrap(),
         A { n: 400 }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "n": 500 })).unwrap(),
+        A::parse_from_json(Some(json!({ "n": 500 }))).unwrap(),
         A { n: 500 }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "n": 530 }))
+        A::parse_from_json(Some(json!({ "n": 530 })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n` verification failed. maximum(500, exclusive: false)"
@@ -88,17 +94,17 @@ fn test_maximum_exclusive() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "n": 400 })).unwrap(),
+        A::parse_from_json(Some(json!({ "n": 400 }))).unwrap(),
         A { n: 400 }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "n": 500 }))
+        A::parse_from_json(Some(json!({ "n": 500 })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n` verification failed. maximum(500, exclusive: true)"
     );
     assert_eq!(
-        A::parse_from_json(json!({ "n": 530 }))
+        A::parse_from_json(Some(json!({ "n": 530 })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n` verification failed. maximum(500, exclusive: true)"
@@ -119,13 +125,13 @@ fn test_max_length() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "value": "abcd" })).unwrap(),
+        A::parse_from_json(Some(json!({ "value": "abcd" }))).unwrap(),
         A {
             value: "abcd".to_string()
         }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "value": "abcdef" }))
+        A::parse_from_json(Some(json!({ "value": "abcdef" })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `value` verification failed. maxLength(5)"
@@ -145,13 +151,13 @@ fn test_min_length() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "value": "abcdef" })).unwrap(),
+        A::parse_from_json(Some(json!({ "value": "abcdef" }))).unwrap(),
         A {
             value: "abcdef".to_string()
         }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "value": "abcd" }))
+        A::parse_from_json(Some(json!({ "value": "abcd" })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `value` verification failed. minLength(5)"
@@ -171,13 +177,13 @@ fn test_pattern() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "value": "[123]" })).unwrap(),
+        A::parse_from_json(Some(json!({ "value": "[123]" }))).unwrap(),
         A {
             value: "[123]".to_string()
         }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "value": "123" }))
+        A::parse_from_json(Some(json!({ "value": "123" })))
             .unwrap_err()
             .into_message(),
         r#"failed to parse "A": field `value` verification failed. pattern("\[.*\]")"#
@@ -197,13 +203,13 @@ fn test_max_items() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["1", "2", "3"] })).unwrap(),
+        A::parse_from_json(Some(json!({ "values": ["1", "2", "3"] }))).unwrap(),
         A {
             values: vec!["1".to_string(), "2".to_string(), "3".to_string()],
         }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["1", "2", "3", "4"] }))
+        A::parse_from_json(Some(json!({ "values": ["1", "2", "3", "4"] })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `values` verification failed. maxItems(3)"
@@ -223,7 +229,7 @@ fn test_min_items() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["1", "2", "3", "4"] })).unwrap(),
+        A::parse_from_json(Some(json!({ "values": ["1", "2", "3", "4"] }))).unwrap(),
         A {
             values: vec![
                 "1".to_string(),
@@ -234,7 +240,7 @@ fn test_min_items() {
         }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["1", "2", "3"] }))
+        A::parse_from_json(Some(json!({ "values": ["1", "2", "3"] })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `values` verification failed. minItems(4)"
@@ -254,13 +260,13 @@ fn test_unique_items() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["1", "2", "3"] })).unwrap(),
+        A::parse_from_json(Some(json!({ "values": ["1", "2", "3"] }))).unwrap(),
         A {
             values: vec!["1".to_string(), "2".to_string(), "3".to_string(),],
         }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["1", "2", "2"] }))
+        A::parse_from_json(Some(json!({ "values": ["1", "2", "2"] })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `values` verification failed. uniqueItems()"
@@ -360,7 +366,7 @@ fn test_option() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "n1": 20 })).unwrap(),
+        A::parse_from_json(Some(json!({ "n1": 20 }))).unwrap(),
         A {
             n1: Some(20),
             n2: None
@@ -368,7 +374,7 @@ fn test_option() {
     );
 
     assert_eq!(
-        A::parse_from_json(json!({ "n2": 20 })).unwrap(),
+        A::parse_from_json(Some(json!({ "n2": 20 }))).unwrap(),
         A {
             n1: None,
             n2: Some(Some(20)),
@@ -376,19 +382,19 @@ fn test_option() {
     );
 
     assert_eq!(
-        A::parse_from_json(json!({ "n2": null })).unwrap(),
+        A::parse_from_json(Some(json!({ "n2": null }))).unwrap(),
         A { n1: None, n2: None }
     );
 
     assert_eq!(
-        A::parse_from_json(json!({ "n1": 25 }))
+        A::parse_from_json(Some(json!({ "n1": 25 })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n1` verification failed. multipleOf(10)"
     );
 
     assert_eq!(
-        A::parse_from_json(json!({ "n2": 25 }))
+        A::parse_from_json(Some(json!({ "n2": 25 })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n2` verification failed. multipleOf(10)"
@@ -403,16 +409,19 @@ fn test_multiple_validators() {
         n: i32,
     }
 
-    assert_eq!(A::parse_from_json(json!({ "n": 20 })).unwrap(), A { n: 20 });
     assert_eq!(
-        A::parse_from_json(json!({ "n": 25 }))
+        A::parse_from_json(Some(json!({ "n": 20 }))).unwrap(),
+        A { n: 20 }
+    );
+    assert_eq!(
+        A::parse_from_json(Some(json!({ "n": 25 })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n` verification failed. multipleOf(10)"
     );
 
     assert_eq!(
-        A::parse_from_json(json!({ "n": 530 }))
+        A::parse_from_json(Some(json!({ "n": 530 })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n` verification failed. maximum(500, exclusive: false)"
@@ -429,12 +438,12 @@ fn test_unsigned_integers() {
         u64: u64,
     }
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "u8": u8::MAX as u64,
             "u16": u16::MAX as u64,
             "u32": u32::MAX as u64,
             "u64": u64::MAX as u64,
-        }))
+        })))
         .unwrap(),
         A {
             u8: u8::MAX,
@@ -444,14 +453,14 @@ fn test_unsigned_integers() {
         }
     );
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "u8": u8::MAX as u64 + 1,
             "u16": u16::MAX as u64,
             "u32": u32::MAX as u64,
             "u64": u64::MAX as u64,
-        }))
-            .unwrap_err()
-            .into_message(),
+        })))
+        .unwrap_err()
+        .into_message(),
         "failed to parse \"integer(uint8)\": Only integers from 0 to 255 are accepted. (occurred while parsing \"A\")"
     );
 }
@@ -465,11 +474,11 @@ fn test_list_on_object() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "n": [1, 2, 3] })).unwrap(),
+        A::parse_from_json(Some(json!({ "n": [1, 2, 3] }))).unwrap(),
         A { n: vec![1, 2, 3] }
     );
     assert_eq!(
-        A::parse_from_json(json!({ "n": [1, 2, 3, 25] }))
+        A::parse_from_json(Some(json!({ "n": [1, 2, 3, 25] })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `n` verification failed. maximum(10, exclusive: false)"
@@ -519,21 +528,21 @@ fn test_both_max_items_and_max_length() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["a", "b"] })).unwrap(),
+        A::parse_from_json(Some(json!({ "values": ["a", "b"] }))).unwrap(),
         A {
             values: vec!["a".to_string(), "b".to_string()]
         }
     );
 
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["a", "b", "c"] }))
+        A::parse_from_json(Some(json!({ "values": ["a", "b", "c"] })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `values` verification failed. maxItems(2)"
     );
 
     assert_eq!(
-        A::parse_from_json(json!({ "values": ["a", "bcde"] }))
+        A::parse_from_json(Some(json!({ "values": ["a", "bcde"] })))
             .unwrap_err()
             .into_message(),
         "failed to parse \"A\": field `values` verification failed. maxLength(3)"
@@ -549,13 +558,13 @@ fn test_max_properties() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "values": {
                 "a": 1,
                 "b": 2,
                 "c": 3,
             },
-        }))
+        })))
         .unwrap(),
         A {
             values: {
@@ -569,14 +578,14 @@ fn test_max_properties() {
     );
 
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "values": {
                 "a": 1,
                 "b": 2,
                 "c": 3,
                 "d": 4,
             },
-        }))
+        })))
         .unwrap_err()
         .into_message(),
         "failed to parse \"A\": field `values` verification failed. maxProperties(3)"
@@ -596,13 +605,13 @@ fn test_min_properties() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "values": {
                 "a": 1,
                 "b": 2,
                 "c": 3,
             },
-        }))
+        })))
         .unwrap(),
         A {
             values: {
@@ -616,11 +625,11 @@ fn test_min_properties() {
     );
 
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "values": {
                 "a": 1,
             },
-        }))
+        })))
         .unwrap_err()
         .into_message(),
         "failed to parse \"A\": field `values` verification failed. minProperties(2)"
@@ -640,13 +649,13 @@ fn test_map_on_object() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "values": {
                 "a": 1,
                 "b": 2,
                 "c": 3,
             },
-        }))
+        })))
         .unwrap(),
         A {
             values: {
@@ -660,12 +669,12 @@ fn test_map_on_object() {
     );
 
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "values": {
                 "a": 1,
                 "b": 101,
             },
-        }))
+        })))
         .unwrap_err()
         .into_message(),
         "failed to parse \"A\": field `values` verification failed. maximum(100, exclusive: false)"
@@ -706,17 +715,17 @@ fn test_custom_validator() {
     }
 
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "value": 150,
-        }))
+        })))
         .unwrap(),
         A { value: 150 }
     );
 
     assert_eq!(
-        A::parse_from_json(json!({
+        A::parse_from_json(Some(json!({
             "value": 200,
-        }))
+        })))
         .unwrap_err()
         .into_message(),
         "failed to parse \"A\": field `value` verification failed. MyIntValidator"
